@@ -1,24 +1,24 @@
 
 if 'bgcolor' in fields:
     bgcolor = fields['bgcolor'].value
-    bgcolorArg = 'bgcolor="%s"' % bgcolor
+    bgcolorArg = 'style="background-color=%s"' % bgcolor
 else:
     bgcolor = ''
     bgcolorArg = ''
 
-print '''<!DOCTYPE HTML SYSTEM>
+print '''<!DOCTYPE html>
 <html>
     <head>
         <title>Colors</title>
     </head>
     <body %s>
-        <h1 align="center">Colors</h1>
+        <h1 style="text-align:center">Colors</h1>
         <center>
         <form action="Colors">
             bgcolor: <input type="text" name="bgcolor" value="%s">
             <input type="submit" value="Go">
         </form>
-        <table cellspacing="2" cellpadding="2">
+        <table>
 ''' % (bgcolorArg, bgcolor)
 
 space = '&nbsp;'*10
@@ -35,7 +35,7 @@ for r in range(11):
             # Compute brightness given RGB
             brightness = (0.3*r**gamma + 0.6*g**gamma + 0.1*b**gamma)**(1/gamma)
             # We then use brightness to determine a good font color for high contrast
-            textcolor = brightness < 0.5 and 'white' or 'black'
+            textcolor = 'white' if brightness < 0.5 else 'black'
             print '<td style="color:%s;background-color:%s;">%s</td>' % (textcolor, color, color)
         print '</tr>'
 
