@@ -104,17 +104,18 @@ class Model(object):
         output.write('use %s;\n\n' % databasename)
 
     def writeInsertSamplesSQL(self, generator, dirname):
-        if self._filename is not None:
-            file = open(os.path.join(dirname, 'InsertSamples.sql'), 'w')
-            self.writeConnectToDatabase(generator, file, self.sqlDatabaseName())
+        if self._filename is None:
+            return
+        with open(os.path.join(dirname, 'InsertSamples.sql'), 'w') as f:
+            self.writeConnectToDatabase(generator, f, self.sqlDatabaseName())
 
-            if self.setting('DoNotSortSQLCreateStatementsByDependency', False):
-                allKlasses = self.allKlassesInOrder()
-            else:
-                allKlasses = self.allKlassesInDependencyOrder()
+            allKlasses = (self.allKlassesInOrder
+                if self.setting('DoNotSortSQLCreateStatementsByDependency', False)
+                else self.allKlassesInDependencyOrder)()
+
+            wr = f.write
 
             # delete the existing data
-            wr = file.write
             for klass in reversed(allKlasses):
                 if not klass.isAbstract():
                     wr('delete from %s;\n' % klass.sqlTableName())
@@ -128,7 +129,7 @@ class Model(object):
                 lines = open(filename).readlines()
                 try:
                     self.writeInsertSamplesSQLForLines(lines, generator, file, filename)
-                except SampleError, s:
+                except SampleError as s:
                     s.write(filename)
                     sys.exit(1)
 
@@ -138,11 +139,10 @@ class Model(object):
                 samples = self._klassSamples.get(klass)
                 if samples is not None:
                     for line in samples:
-                        file.write(line)
-                self.writePostKlassSamplesSQL(generator, file)
+                        wr(line)
+                self.writePostKlassSamplesSQL(generator, f)
 
-            self.writePostSamplesSQL(generator, file)
-            file.close()
+            self.writePostSamplesSQL(generator, f)
 
             del self._klassSamples
 
@@ -160,7 +160,7 @@ class Model(object):
                 linenum += 1
                 try:
                     fields = parse(line)
-                except CSVParser.ParseError, err:
+                except CSVParser.ParseError as err:
                     raise SampleError(linenum, 'Syntax error: %s' % err)
                 if fields is None:
                     # parser got embedded newline; continue with next line
@@ -672,7 +672,7 @@ class Attr(object):
 
     def uniqueSQL(self):
         """Return SQL to use within a column definition to make it unique."""
-        return self.boolForKey('isUnique') and ' unique' or ''
+        return ' unique' if self.boolForKey('isUnique') else ''
 
 
 class BoolAttr(object):
@@ -709,7 +709,7 @@ class IntAttr(object):
                 value = value[:-2]
             try:
                 int(value)  # raises exception if value is invalid
-            except ValueError, e:
+            except ValueError as e:
                 raise ValueError('%s (attr is %s)' (e, self.name()))
             return str(value)
 
