@@ -3,12 +3,12 @@
 Enhance sys.path so that we're guaranteed to import the MiddleKit that
 we reside in. This is particularly important for Webware developers
 that might have more than one Webware source tree on their file system.
-
 """
 
 
 # We're located at .../MiddleKit/Run/Tests/Test.py.
-import os, sys
+import os
+import sys
 
 if sys.path[0] not in ('', '.'):
     sys.path.insert(0, '')
