@@ -3,7 +3,6 @@
 UserManagers can save their data to files, or to a MiddleKit database.
 For MiddleKit, the database can be MySQL, PostgreSQL, MSSQL or SQLite,
 but we test only with the SQLite database.
-
 """
 
 import os
@@ -19,8 +18,6 @@ webwarePath = os.path.dirname(os.path.dirname(testDir))
 if sys.path[0] != webwarePath:
     sys.path.insert(0, webwarePath)
 
-import AllTests
-
 
 class UserManagerTest(unittest.TestCase):
     """Tests for the base UserManager class."""
@@ -64,11 +61,10 @@ class _UserManagerToSomewhereTest(UserManagerTest):
     This abstract class provides some tests that all user managers should pass.
     Subclasses are responsible for overriding setUp() and tearDown() for which
     they should invoke super.
-
     """
 
     def setUp(self):
-        pass # nothing for no
+        pass  # nothing for no
 
     def tearDown(self):
         self._mgr = None
@@ -83,7 +79,7 @@ class _UserManagerToSomewhereTest(UserManagerTest):
         self.assertEqual(mgr.userForSerialNum(user.serialNum()), user)
         self.assertEqual(mgr.userForExternalId(user.externalId()), user)
         self.assertEqual(mgr.userForName(user.name()), user)
-        externalId = user.externalId() # for use later in testing
+        externalId = user.externalId()  # for use later in testing
 
         users = mgr.users()
         self.assertEqual(len(users), 1)
@@ -156,9 +152,10 @@ class _UserManagerToSomewhereTest(UserManagerTest):
     def testDuplicateUser(self):
         mgr = self._mgr
         user = self._user = mgr.createUser('foo', 'bar')
-        self.assertRaises(AssertionError, mgr.createUser, 'foo', 'bar')
+        self.assertEqual(user.name(), 'foo')
+        self.assertRaises(KeyError, mgr.createUser, 'foo', 'bar')
         userClass = mgr.userClass()
-        self.assertRaises(AssertionError, userClass, mgr, 'foo', 'bar')
+        self.assertRaises(KeyError, userClass, mgr, 'foo', 'bar')
 
 
 class UserManagerToFileTest(_UserManagerToSomewhereTest):
