@@ -91,7 +91,6 @@ class UserManager(object):
 
     Please read the method docstrings and other class documentation to
     fully understand UserKit.
-
     """
 
 
@@ -113,7 +112,6 @@ class UserManager(object):
         """Perform any tasks necessary to shut down the user manager.
 
         Subclasses may override and must invoke super as their *last* step.
-
         """
         pass
 
@@ -124,7 +122,6 @@ class UserManager(object):
         """Return the userClass, which is used by createUser.
 
         The default value is UserKit.User.User.
-
         """
         if self._userClass is None:
             self.setUserClass(User)
@@ -134,9 +131,9 @@ class UserManager(object):
         """Set the userClass, which cannot be None and must inherit from User.
 
         See also: userClass().
-
         """
-        assert issubclass(userClass, User)
+        if not issubclass(userClass, User):
+            raise TypeError('%s is not a User class' % (userClass,))
         self._userClass = userClass
 
     def modifiedUserTimeout(self):
@@ -168,7 +165,6 @@ class UserManager(object):
         This method invokes self.addUser().
 
         See also: userClass(), setUserClass()
-
         """
         if userClass is None:
             userClass = self.userClass()
@@ -177,16 +173,17 @@ class UserManager(object):
         return user
 
     def addUser(self, user):
-        assert isinstance(user, User)
+        if not isinstance(user, User):
+            raise TypeError('%s is not a User object' % (user,))
         self._cachedUsers.append(user)
-        assert user.serialNum() not in self._cachedUsersBySerialNum
+        if user.serialNum() in self._cachedUsersBySerialNum:
+            raise KeyError('a user with this number already exists')
         self._cachedUsersBySerialNum[user.serialNum()] = user
 
     def userForSerialNum(self, serialNum, default=NoDefault):
         """Return the user with the given serialNum.
 
         The user record is pulled into memory if needed.
-
         """
         raise AbstractError(self.__class__)
 
@@ -194,7 +191,6 @@ class UserManager(object):
         """Return the user with the given external id.
 
         The user record is pulled into memory if needed.
-
         """
         raise AbstractError(self.__class__)
 
@@ -202,7 +198,6 @@ class UserManager(object):
         """Return the user with the given name.
 
         The user record is pulled into memory if needed.
-
         """
         raise AbstractError(self.__class__)
 
@@ -226,14 +221,16 @@ class UserManager(object):
 
     def login(self, user, password):
         """Return the user if the login is successful, otherwise return None."""
-        assert isinstance(user, User)
+        if not isinstance(user, User):
+            raise TypeError('%s is not a User object' % (user,))
         result = user.login(password, fromMgr=True)
         if result:
             self._numActive += 1
         return result
 
     def logout(self, user):
-        assert isinstance(user, User)
+        if not isinstance(user, User):
+            raise TypeError('%s is not a User object' % (user,))
         user.logout(fromMgr=True)
         self._numActive -= 1
 
@@ -269,7 +266,6 @@ class UserManager(object):
         then consistency problems could occur.
 
         The most popular use of this method is in the regression test suite.
-
         """
         self._cachedUsers = []
         self._cachedUsersBySerialNum = {}
