@@ -364,7 +364,7 @@ class FCGI(object):
         method = 'GET'
         if 'REQUEST_METHOD' in self.env:
             method = self.env['REQUEST_METHOD'].upper()
-        return cgi.FieldStorage(fp=method != 'GET' and self.inp or None,
+        return cgi.FieldStorage(fp=self.inp if method != 'GET' else None,
             environ=self.env, keep_blank_values=1)
 
     def getNextChunk(self, data):
@@ -381,8 +381,8 @@ def _startup():
         s = socket.fromfd(sys.stdin.fileno(),
             socket.AF_INET, socket.SOCK_STREAM)
         s.getpeername()
-    except socket.error, (err, errmsg):
-        if err != errno.ENOTCONN:  # must be a non-fastCGI environment
+    except socket.error as err:
+        if err.errno != errno.ENOTCONN:  # must be a non-fastCGI environment
             global _isFCGI
             _isFCGI = False
             return
@@ -434,9 +434,9 @@ def _test():
             req.Finish()
     except Exception:
         import traceback
-        f = open('traceback', 'w')
-        traceback.print_exc(file=f)
-        # f.write('%s' % doc)
+        with open('traceback', 'w') as f:
+            traceback.print_exc(file=f)
+            # f.write('%s' % doc)
 
 
 if __name__ == '__main__':
