@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 
 """The Application singleton.
 
@@ -52,6 +52,7 @@ defaultConfig = dict(
     SessionPrefix = '',
     SessionName = '_SID_',
     AlwaysSaveSessions = True,
+    RetainSessions = True,
     IgnoreInvalidSession = True,
     UseAutomaticPathSessions = False,
     UseCookieSessions = True,
@@ -173,8 +174,8 @@ class Application(ConfigurableForServerSidePath):
         # sessions, in case the loading of the sessions causes an exception.
         self._exceptionHandlerClass = ExceptionHandler
 
-        self.initSessions()
         self.makeDirs()
+        self.initSessions()
 
         URLParser.initApp(self)
         self._rootURLParser = URLParser.ContextParser(self)
@@ -220,6 +221,7 @@ class Application(ConfigurableForServerSidePath):
             self.defaultConfig()['SessionName'])
         self._autoPathSessions = self.setting('UseAutomaticPathSessions')
         self._alwaysSaveSessions = self.setting('AlwaysSaveSessions')
+        self._retainSessions = self.setting('RetainSessions')
         moduleName = self.setting('SessionModule')
         className = moduleName.rsplit('.', 1)[-1]
         try:
@@ -236,8 +238,6 @@ class Application(ConfigurableForServerSidePath):
         if moduleName in (
                 'Dynamic', 'File', 'Memcached', 'Memory', 'Redis', 'Shelve'):
             moduleName = 'Session%sStore' % moduleName
-        self._sessionDir = self.serverSidePath(
-            self.setting('SessionStoreDir') or 'Sessions')
         className = moduleName.rsplit('.', 1)[-1]
         try:
             exec 'from %s import %s' % (moduleName, className)
@@ -256,6 +256,8 @@ class Application(ConfigurableForServerSidePath):
             self.setting('CacheDir') or 'Cache')
         self._errorMessagesDir = self.serverSidePath(
             self.setting('ErrorMessagesDir') or 'ErrorMsgs')
+        self._sessionDir = self.serverSidePath(
+            self.setting('SessionStoreDir') or 'Sessions')
         for path in (self.serverSidePath('Logs'),
                 self._cacheDir, self._errorMessagesDir, self._sessionDir):
             if path and not os.path.exists(path):
