@@ -57,15 +57,14 @@ class HTTPRequest(Request):
 
         # Debugging
         if debug:
-            f = open('env.text', 'a')
-            save = sys.stdout
-            sys.stdout = f
-            print '>> env for request:'
-            for key in sorted(env):
-                print '%s: %s' % (repr(key), repr(env[key]))
-            print
-            sys.stdout = save
-            f.close()
+            with open('env.text', 'a') as f:
+                save = sys.stdout
+                sys.stdout = f
+                print '>> env for request:'
+                for key in sorted(env):
+                    print '%s: %s' % (repr(key), repr(env[key]))
+                print
+                sys.stdout = save
 
         # Get adapter, servlet path and query string
         self._absolutepath = 'WK_ABSOLUTE' in env  # set by adapter
@@ -86,7 +85,7 @@ class HTTPRequest(Request):
             # correct servletPath if there was a redirection
             if not (self._uri + '/').startswith(self._servletPath + '/'):
                 i = self._uri.find(self._pathInfo)
-                self._servletPath = i > 0 and self._uri[:i] or ''
+                self._servletPath = self._uri[:i] if i > 0 else ''
         else:
             # REQUEST_URI isn't actually part of the CGI standard and some
             # web servers like IIS don't set it (as of 8/22/2000).
@@ -95,7 +94,7 @@ class HTTPRequest(Request):
                 # correct servletPath if there was a redirection
                 if not (self._uri + '/').startswith(self._servletPath + '/'):
                     i = self._uri.find(self._pathInfo)
-                    self._servletPath = i > 0 and self._uri[:i] or ''
+                    self._servletPath = self._uri[:i] if i > 0 else ''
             else:
                 self._uri = self._servletPath + self._pathInfo
             if self._queryString:
@@ -418,7 +417,7 @@ class HTTPRequest(Request):
 
     def scheme(self):
         """Return the URI scheme of the request (http or https)."""
-        return self.isSecure() and 'https' or 'http'
+        return 'https' if self.isSecure() else 'http'
 
     def hostAndPort(self):
         """Return the hostname and port part from the URL of this request."""
@@ -430,7 +429,7 @@ class HTTPRequest(Request):
         else:
             host = env.get('SERVER_ADDR', '') or 'localhost'
             port = env.get('SERVER_PORT', '')
-            defaultPort = self.isSecure() and '443' or '80'
+            defaultPort = '443' if self.isSecure() else '80'
             if port and port != defaultPort:
                 host += ':' + port
             return host
@@ -862,14 +861,14 @@ def htmlInfo(info):
 
     Useful for inspecting objects via web browsers.
     """
-    res = ['<table border="1">\n']
+    res = ['<table>\n']
     for pair in info:
         value = pair[1]
         if hasattr(value, 'items') and (isinstance(value, dict)
                 or hasattr(value, '__getitem__')):
             value = htmlInfo(_infoForDict(value))
-        res.append('<tr valign="top"><td>%s</td><td>%s&nbsp;</td></tr>\n'
-            % (pair[0], value))
+        res.append('<tr style="vertical-align:top"><td>%s</td>'
+            '<td>%s&nbsp;</td></tr>\n' % (pair[0], value))
     res.append('</table>\n')
     return ''.join(res)
 
