@@ -11,5 +11,5 @@ class Servlet(Page):
         self.writeln('<h2>WebKit Testing Servlet</h2>')
         self.writeln('<h3>%s</h3>' % self.title())
         req = self.request()
-        self.writeln("<p>serverSidePath = <tt>%s</tt></p>" % req.serverSidePath())
-        self.writeln("<p>extraURLPath = <tt>%s</tt></p>" % req.extraURLPath())
+        self.writeln("<p>serverSidePath = <code>%s</code></p>" % req.serverSidePath())
+        self.writeln("<p>extraURLPath = <code>%s</code></p>" % req.extraURLPath())
