@@ -7,13 +7,14 @@ class Inspector(Page):
     def writeContent(self):
         req = self.request()
         self.write('Path:<br>\n')
-        self.write('<tt>%s</tt><p>\n'
+        self.write('<code>%s</code><p>\n'
             % htmlEncode(req.extraURLPath()))
         self.write('Variables:<br>\n')
-        self.write('<table border="1">')
+        self.write('<table>')
         for name in sorted(req.fields()):
-            self.write('<tr><td align="right">%s:</td><td>%s</td></tr>\n'
+            self.write(
+                '<tr><td style="text-align:right">%s:</td><td>%s</td></tr>\n'
                 % (htmlEncode(name), htmlEncode(req.field(name))))
         self.write('</table><p>\n')
         self.write('Server-side path:<br>\n')
-        self.write('<tt>%s</tt><p>\n' % req.serverSidePath())
+        self.write('<code>%s</code><p>\n' % req.serverSidePath())
